
@ECHO off

REM ========================================================================
REM   Bank Demo Script
REM   
REM   DESCRIPTION:
REM     This script creates the Bank Demo database, enables it for
REM     spatial operations, loads data, and creates views to implement
REM     spatial queries.
REM   
REM   STEPS:
REM   - Stop and restart the database
REM   - Create database and update configuration parameters
REM   - Create bufferpool and temporary table space
REM   - Stop and restart the database
REM   - Enable database with Spatial Extender
REM   - Connect to database
REM   - Create data tables
REM   - Import data
REM   - Alter data tables adding spatial column
REM   - Run geocoder on data tables
REM   - Import shapefiles with background map data
REM   - Create indexes
REM   - Update statistics
REM   - Create views that implement spatial queries
REM   - Grant privileges on tables, views, methods
REM   - Register data, map, and view layers
REM   - Reset database connections
REM   
REM ========================================================================

set DBNAME=%~n0
set DEMOPATH=%~d0%~p0

prompt [$T] 

@ECHO on

@ECHO === Stop and restart the database ====================================

db2 connect reset
db2stop
db2start

@ECHO === Create database and update configuration parameters ==============

db2 drop database %DBNAME%
db2 create database %DBNAME%
db2 update db cfg for %DBNAME% using logfilsiz 1000
db2 update db cfg for %DBNAME% using logprimary 10
db2 update db cfg for %DBNAME% using logsecond 2
db2 update db cfg for %DBNAME% using applheapsz 2048
db2 update db cfg for %DBNAME% using app_ctl_heap_sz 1024

db2 update db cfg for %DBNAME% using stmtheap 4096

@ECHO === Creates bufferpool and temporary table space =====================

db2 connect to %DBNAME%
db2 create bufferpool gse size 1024 pagesize 32 k
db2 create temporary tablespace tempspace2 pagesize 32 k  managed by system  using ('banktemp') extentsize 32 overhead 24.1 prefetchsize 16 transferrate 0.9 bufferpool gse

@ECHO === Stop and restart the database ====================================

db2 connect reset
db2stop
db2start

@ECHO === Enable database with Spatial Extender ============================

db2se enable_db %DBNAME%

@ECHO === Connect to database ==============================================

db2 connect to %DBNAME%

@ECHO === Create data tables ===============================================

db2 -twvf create_tables.db2

@ECHO === Import data ======================================================

erase Data\*.msg

db2 -twvf import_data.db2

@ECHO === Alter data tables adding spatial column ==========================

db2 -twvf alter_tables.db2

@ECHO === Run geocoder on data tables ======================================

db2se run_gc %DBNAME% -tableSchema bankdemo -tableName customer -columnName feature -geocoderName DB2SE_USA_GEOCODER -parameterValues "STREET,CITY,STATE,ZIP,,,55,,,,'%DEMOPATH%Refdata\santa_clara.edg',"
db2se run_gc %DBNAME% -tableSchema bankdemo -tableName branch   -columnName feature -geocoderName DB2SE_USA_GEOCODER -parameterValues "STREET,CITY,STATE,ZIP,,,55,,,,'%DEMOPATH%Refdata\santa_clara.edg',"

@ECHO === Import shapefiles with background map data =======================

erase Maps\*.msg

db2se import_shape %DBNAME% -tableSchema bankdemo -tableName sanjose   -spatialColumn feature -idColumn se_row_id -fileName "%DEMOPATH%Maps\BackGround.shp" -messagesFile "%DEMOPATH%Maps\BackGround.msg" -srsName NAD83_SRS_1
db2se import_shape %DBNAME% -tableSchema bankdemo -tableName mainroads -spatialColumn feature -idColumn se_row_id -fileName "%DEMOPATH%Maps\SJRoads.shp" -messagesFile "%DEMOPATH%Maps\SJRoads.msg" -srsName NAD83_SRS_1
db2se import_shape %DBNAME% -tableSchema bankdemo -tableName selblocks -spatialColumn feature -idColumn se_row_id -fileName "%DEMOPATH%Maps\Sel_block2000.shp" -messagesFile "%DEMOPATH%Maps\Sel_block2000.msg" -srsName NAD83_SRS_1

@ECHO === Create indexes ===================================================

db2 -twvf create_indexes.db2

@ECHO === Update statistics ================================================

db2 -twvf update_statistics.db2

@ECHO === Create views that implement spatial queries ======================

db2 -twvf create_views.db2

@ECHO === Grant privileges on tables, views, methods =======================

db2 -twvf grant_privileges.db2

@ECHO === Register data, map, and view layers ==============================

db2se register_spatial_column %DBNAME% -tableSchema bankdemo -tableName customer -columnName feature -srsName NAD83_SRS_1
db2se register_spatial_column %DBNAME% -tableSchema bankdemo -tableName branch   -columnName feature -srsName NAD83_SRS_1

db2se register_spatial_column %DBNAME% -tableSchema bankdemo -tableName sanjose   -columnName feature -srsName NAD83_SRS_1
db2se register_spatial_column %DBNAME% -tableSchema bankdemo -tableName mainroads -columnName feature -srsName NAD83_SRS_1
db2se register_spatial_column %DBNAME% -tableSchema bankdemo -tableName selblocks -columnName feature -srsName NAD83_SRS_1

db2se register_spatial_column %DBNAME% -tableSchema bankdemo -tableName v08 -columnName feature -srsName NAD83_SRS_1
db2se register_spatial_column %DBNAME% -tableSchema bankdemo -tableName v09 -columnName feature -srsName NAD83_SRS_1
db2se register_spatial_column %DBNAME% -tableSchema bankdemo -tableName v03 -columnName feature -srsName NAD83_SRS_1
db2se register_spatial_column %DBNAME% -tableSchema bankdemo -tableName v02 -columnName feature -srsName NAD83_SRS_1
db2se register_spatial_column %DBNAME% -tableSchema bankdemo -tableName v07 -columnName feature -srsName NAD83_SRS_1
db2se register_spatial_column %DBNAME% -tableSchema bankdemo -tableName v05 -columnName feature -srsName NAD83_SRS_1
db2se register_spatial_column %DBNAME% -tableSchema bankdemo -tableName v06 -columnName feature -srsName NAD83_SRS_1
db2se register_spatial_column %DBNAME% -tableSchema bankdemo -tableName v04 -columnName feature -srsName NAD83_SRS_1
db2se register_spatial_column %DBNAME% -tableSchema bankdemo -tableName v01 -columnName feature -srsName NAD83_SRS_1
db2se register_spatial_column %DBNAME% -tableSchema bankdemo -tableName v10 -columnName feature -srsName NAD83_SRS_1
db2se register_spatial_column %DBNAME% -tableSchema bankdemo -tableName v11 -columnName feature -srsName NAD83_SRS_1
db2se register_spatial_column %DBNAME% -tableSchema bankdemo -tableName v12 -columnName feature -srsName NAD83_SRS_1

@ECHO === Select rows counts ===============================================

db2 -twvf select_count.db2

@ECHO === Reset database connections =======================================

db2 connect reset

@ECHO === End of demo setup script =========================================

prompt

